# Makeflow Example

See [this page on the HERA wiki](http://hera.pbworks.com/w/page/124165410/Makeflow%20example)
for a worked example of how to generate a makeflow file from a config file, and
run the resulting pipeline.
